@@ -22,11 +22,10 @@ from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OSupervisedAlgorithmWithFoldColumn import H2OSupervisedAlgorithmWithFoldColumn
 from ai.h2o.sparkling.ml.models.H2ODeepLearningMOJOModel import H2ODeepLearningMOJOModel
 from ai.h2o.sparkling.ml.params.H2ODeepLearningParams import H2ODeepLearningParams
-from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.DistributionBasedH2OTrainFramePreparation import DistributionBasedH2OTrainFramePreparation
 
 
-class H2ODeepLearning(H2ODeepLearningParams, H2OCommonParams, H2OSupervisedAlgorithmWithFoldColumn, DistributionBasedH2OTrainFramePreparation):
+class H2ODeepLearning(H2ODeepLearningParams, H2OSupervisedAlgorithmWithFoldColumn, DistributionBasedH2OTrainFramePreparation):
 
     @keyword_only
     def __init__(self,
@@ -34,7 +33,9 @@ class H2ODeepLearning(H2ODeepLearningParams, H2OCommonParams, H2OSupervisedAlgor
                  initialWeights=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -82,7 +83,6 @@ class H2ODeepLearning(H2ODeepLearningParams, H2OCommonParams, H2OSupervisedAlgor
                  quietMode=False,
                  scoreValidationSampling="Uniform",
                  overwriteWithBestModel=True,
-                 autoencoder=False,
                  useAllFactorLevels=True,
                  standardize=True,
                  diagnostics=True,
@@ -138,6 +138,9 @@ class H2ODeepLearning(H2ODeepLearningParams, H2OCommonParams, H2OSupervisedAlgor
                 kwargs['calculateFeatureImportances'] = kwargs['variableImportances']
             del kwargs['variableImportances']
             warn("The parameter 'variableImportances' is deprecated and will be removed in the version 3.36.")
+        if 'autoencoder' in kwargs:
+            del kwargs['autoencoder']
+            warn("The parameter 'autoencoder' is deprecated and will be removed in the version 3.36.")
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
