@@ -22,18 +22,19 @@ from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OUnsupervisedAlgorithm import H2OUnsupervisedAlgorithm
 from ai.h2o.sparkling.ml.models.H2OKMeansMOJOModel import H2OKMeansMOJOModel
 from ai.h2o.sparkling.ml.params.H2OKMeansParams import H2OKMeansParams
-from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.H2OKMeansExtras import H2OKMeansExtras
 
 
-class H2OKMeans(H2OKMeansParams, H2OCommonParams, H2OUnsupervisedAlgorithm, H2OKMeansExtras):
+class H2OKMeans(H2OKMeansParams, H2OUnsupervisedAlgorithm, H2OKMeansExtras):
 
     @keyword_only
     def __init__(self,
                  userPoints=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
@@ -63,16 +64,14 @@ class H2OKMeans(H2OKMeansParams, H2OCommonParams, H2OUnsupervisedAlgorithm, H2OK
                  ignoreConstCols=True,
                  scoreEachIteration=False,
                  maxRuntimeSecs=0.0,
-                 exportCheckpointsDir=None,
-                 **kwargs):
+                 exportCheckpointsDir=None):
         Initializer.load_sparkling_jar()
         super(H2OKMeans, self).__init__()
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OKMeans", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        if 'weightCol' in kwargs:
-            del kwargs['weightCol']
-            warn("The parameter 'weightCol' is deprecated and will be removed in the version 3.34.")
+        kwargs = self._updateInitKwargs(kwargs)
+
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
         self._set(**kwargs)
