@@ -29,7 +29,9 @@ class H2ODRFRegressor(H2ODRF):
                  calibrationDataFrame=None,
                  ignoredCols=None,
                  columnsToCategorical=[],
+                 keepBinaryModels=False,
                  withContributions=False,
+                 dataFrameSerializer="ai.h2o.sparkling.utils.JSONDataFrameSerializer",
                  withLeafNodeAssignments=False,
                  namedMojoOutputColumns=True,
                  convertInvalidNumbersToNa=False,
