@@ -228,13 +228,13 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     scale = Param(
         Params._dummy(),
         "scale",
-        """Smoothing parameter for gam predictors""",
+        """Smoothing parameter for gam predictors.  If specified, must be of the same length as gam_columns""",
         H2OTypeConverters.toNullableListFloat())
 
     bs = Param(
         Params._dummy(),
         "bs",
-        """Basis function type for each gam predictors, 0 for cr""",
+        """Basis function type for each gam predictors, 0 for cr, 1 for thin plate regression with knots, 2 for thin plate regression with SVD.  If specified, must be the same size as gam_columns""",
         H2OTypeConverters.toNullableListInt())
 
     keepGamCols = Param(
@@ -243,10 +243,22 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
         """Save keys of model matrix""",
         H2OTypeConverters.toBoolean())
 
+    standardizeTpGamCols = Param(
+        Params._dummy(),
+        "standardizeTpGamCols",
+        """standardize tp (thin plate) predictor columns""",
+        H2OTypeConverters.toBoolean())
+
+    scaleTpPenaltyMat = Param(
+        Params._dummy(),
+        "scaleTpPenaltyMat",
+        """Scale penalty matrix for tp (thin plate) smoothers as in R""",
+        H2OTypeConverters.toBoolean())
+
     knotIds = Param(
         Params._dummy(),
         "knotIds",
-        """String arrays storing frame keys of knots.  One for each gam column specified in gam_columns""",
+        """String arrays storing frame keys of knots.  One for each gam column set specified in gam_columns""",
         H2OTypeConverters.toNullableListString())
 
     modelId = Param(
@@ -288,7 +300,7 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     weightCol = Param(
         Params._dummy(),
         "weightCol",
-        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor.""",
+        """Column with observation weights. Giving some observation a weight of zero is equivalent to excluding it from the dataset; giving an observation a relative weight of 2 is equivalent to repeating that row twice. Negative weights are not allowed. Note: Weights are per-row observation weights and do not increase the size of the data frame. This is typically the number of times a row is repeated, but non-integer values are supported as well. During training, rows with higher weights matter more, due to the larger loss function pre-factor. If you set weight = 0 for a row, the returned prediction frame at that row is zero and this is incorrect. To get an accurate prediction, remove all rows with weight == 0.""",
         H2OTypeConverters.toNullableString())
 
     offsetCol = Param(
@@ -474,6 +486,12 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def getKeepGamCols(self):
         return self.getOrDefault(self.keepGamCols)
 
+    def getStandardizeTpGamCols(self):
+        return self.getOrDefault(self.standardizeTpGamCols)
+
+    def getScaleTpPenaltyMat(self):
+        return self.getOrDefault(self.scaleTpPenaltyMat)
+
     def getKnotIds(self):
         return self.getOrDefault(self.knotIds)
 
@@ -645,6 +663,12 @@ class H2OGAMParams(HasIgnoredCols, HasBetaConstraints, HasGamCols, Params):
     def setKeepGamCols(self, value):
         return self._set(keepGamCols=value)
 
+    def setStandardizeTpGamCols(self, value):
+        return self._set(standardizeTpGamCols=value)
+
+    def setScaleTpPenaltyMat(self, value):
+        return self._set(scaleTpPenaltyMat=value)
+
     def setKnotIds(self, value):
         return self._set(knotIds=value)
 
